@@ -6,7 +6,7 @@
 import math
 import click
 from ..context import get_default_gateway
-from ..paramtypes import CanFrameType, CanFilterType
+from ..paramtypes import CanFrameType, CanFilterType, CanbusRange
 from ..status import run_job_output
 
 @click.group(name='canbus')
@@ -16,28 +16,85 @@ def canbus():
     """
     pass
 
-@canbus.command()
+@canbus.command('list')
 @click.pass_context
 @click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
+def list_(ctx, gateway):
+    if gateway is None:
+        gateway = get_default_gateway(ctx)
+
+    session = ctx.obj.session
+    resp = session.can_list(gateway)
+    for interface in resp.json()['interfaces']:
+        print(interface)
+
+
+@canbus.command()
+@click.pass_context
+@click.argument('interfaces', type=CanbusRange())
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
 @click.option('--bitrate', required=True, type=click.INT, help='bus bitrate e.g. 500000, 250000, etc')
-def up(ctx, gateway, bitrate):
+def up(ctx, interfaces, gateway, bitrate):
     """
         Bring up the CAN Bus at the specified bitrate
+
+        INTERFACES can be an integer, a dash-separated range of integers, or a comma-separated list
+        of ranges or integers.
+
+        Examples:
+
+            \b
+            lager canbus up 0      # Bring up canbus interface 0
+            lager canbus up 0-1    # Bring up canbus interfaces 0 and 1
+            lager canbus up 0,2    # Bring up canbus interfaces 0 and 2
+            lager canbus up 0-1,3  # Bring up canbus interfaces 0, 1, and 3
+
+        Use `lager canbus list` to view available INTERFACES.
     """
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
     session = ctx.obj.session
-    resp = session.can_up(gateway, bitrate)
-    print(resp.json())
+    resp = session.can_up(gateway, bitrate, interfaces)
+    print(resp.json()['message'])
+
+@canbus.command()
+@click.pass_context
+@click.argument('interfaces', type=CanbusRange())
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
+def down(ctx, interfaces, gateway):
+    """
+        Bring down the CAN Bus at the specified bitrate
+
+        INTERFACES can be an integer, a dash-separated range of integers, or a comma-separated list
+        of ranges or integers.
+
+        Examples:
+
+            \b
+            lager canbus down 0      # Bring down canbus interface 0
+            lager canbus down 0-1    # Bring down canbus interfaces 0 and 1
+            lager canbus down 0,2    # Bring down canbus interfaces 0 and 2
+            lager canbus down 0-1,3  # Bring down canbus interfaces 0, 1, and 3
+
+        Use `lager canbus list` to view available INTERFACES.
+    """
+    if gateway is None:
+        gateway = get_default_gateway(ctx)
+
+    session = ctx.obj.session
+    resp = session.can_down(gateway, interfaces)
+    print(resp.json()['message'])
+
 
 @canbus.command()
 @click.pass_context
 @click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
+@click.argument('interface', type=click.INT, required=True)
 @click.argument('can_frames', required=True, nargs=-1, type=CanFrameType())
-def send(ctx, gateway, can_frames):
+def send(ctx, gateway, interface, can_frames):
     """
-        Send a frame on the CAN bus
+        Send a frame on the specified CAN bus
 
         CAN_FRAME format:
 
@@ -71,15 +128,16 @@ def send(ctx, gateway, can_frames):
         gateway = get_default_gateway(ctx)
 
     session = ctx.obj.session
-    resp = session.can_send(gateway, can_frames)
+    resp = session.can_send(gateway, interface, can_frames)
     print(resp.json())
 
 
 @canbus.command()
 @click.pass_context
 @click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
+@click.argument('interface', type=click.INT, required=True)
 @click.argument('filters', required=False, nargs=-1, type=CanFilterType())
-def dump(ctx, gateway, filters):
+def dump(ctx, gateway, interface, filters):
     """
         Dump CAN bus traffic (use Ctrl-C to terminate)
 
@@ -94,12 +152,12 @@ def dump(ctx, gateway, filters):
         Examples:
 
         \b
-        lager canbus dump 92345678:DFFFFFFF
-            (match only for extended CAN ID 12345678)
+        lager canbus dump 0 92345678:DFFFFFFF
+            (match only for extended CAN ID 12345678 on interface 0)
 
         \b
-        lager canbus dump 123:7FF
-            (matches CAN ID 123 - including EFF and RTR frames)
+        lager canbus dump 0 123:7FF
+            (matches CAN ID 123 - including EFF and RTR frames on interface 0)
     """
     if gateway is None:
         gateway = get_default_gateway(ctx)
@@ -108,7 +166,7 @@ def dump(ctx, gateway, filters):
     can_options = {
         'filters': [canfilter._asdict() for canfilter in filters],
     }
-    can_session = session.can_dump(gateway, can_options).json()
+    can_session = session.can_dump(gateway, interface, can_options).json()
     job_id = can_session['test_run']['id']
 
     connection_params = ctx.obj.websocket_connection_params(socktype='job', job_id=job_id)
