@@ -14,6 +14,7 @@ from .config import read_config_file
 from .context import LagerContext
 
 from .gateway.commands import _gateway
+from .adc.commands import adc
 from .setter.commands import setter
 from .lister.commands import lister
 from .auth import load_auth
@@ -34,6 +35,8 @@ from .gpio.commands import gpio
 from .openocd.commands import openocd
 from .python.commands import python
 from .wifi.commands import _wifi
+from .serial_ports.commands import serial_ports
+from .util import check_version
 
 def _decode_environment():
     for key in os.environ:
@@ -45,7 +48,8 @@ def _decode_environment():
 @click.option('--version', 'see_version', is_flag=True, help='See package version')
 @click.option('--debug', 'debug', is_flag=True, help='Show debug output', default=False)
 @click.option('--colorize', 'colorize', is_flag=True, help='Color output', default=False)
-def cli(ctx=None, see_version=None, debug=False, colorize=False):
+@click.option('--version-check/--no-version-check', is_flag=True, help='Check for new version on PyPI', default=True)
+def cli(ctx=None, see_version=None, debug=False, colorize=False, version_check=True):
     """
         Lager CLI
     """
@@ -61,9 +65,12 @@ def cli(ctx=None, see_version=None, debug=False, colorize=False):
         os_args = click.get_os_args()
         help_invoked = '--help' in os_args
         skip_auth = ctx.invoked_subcommand in ('login', 'logout', 'set', 'devenv', 'exec') or help_invoked
+        if version_check and not skip_auth:
+            check_version('lager-cli', __version__)
         setup_context(ctx, debug, colorize, skip_auth)
 
 cli.add_command(_gateway)
+cli.add_command(adc)
 cli.add_command(setter)
 cli.add_command(lister)
 cli.add_command(login)
@@ -85,6 +92,7 @@ cli.add_command(gpio)
 cli.add_command(openocd)
 cli.add_command(python)
 cli.add_command(_wifi)
+cli.add_command(serial_ports)
 
 def setup_context(ctx, debug, colorize, skip_auth):
     """
@@ -103,7 +111,7 @@ def setup_context(ctx, debug, colorize, skip_auth):
 
         if not auth:
             click.echo('Please login using `lager login` first')
-            click.get_current_context().exit(0)
+            click.get_current_context().exit(1)
 
     config = read_config_file()
     ctx.obj = LagerContext(
