@@ -121,7 +121,10 @@ class LagerSession(BaseUrlSession):
                 click.secho(error['description'], fg='red', err=True)
             ctx.exit(1)
         if r.status_code >= 500:
-            click.secho('Something went wrong with the Lager API', fg='red', err=True)
+            if True:
+                print(r.text)
+            else:
+                click.secho('Something went wrong with the Lager API', fg='red', err=True)
             ctx.exit(1)
 
         r.raise_for_status()
@@ -370,26 +373,53 @@ class LagerSession(BaseUrlSession):
         url = 'gateway/{}/wifi/delete-connection'.format(quote(gateway))
         return self.post(url, json={'ssid': ssid})
 
-    def can_up(self, gateway, bitrate):
+    def can_up(self, gateway, bitrate, interfaces):
         """
             Bring up the CAN bus
         """
         url = 'gateway/{}/canbus/up'.format(quote(gateway))
-        return self.post(url, json={'bitrate': bitrate})
+        return self.post(url, json={'bitrate': bitrate, 'interfaces': interfaces})
 
-    def can_send(self, gateway, frames):
+    def can_down(self, gateway, interfaces):
+        """
+            Bring down the CAN bus
+        """
+        url = 'gateway/{}/canbus/down'.format(quote(gateway))
+        return self.post(url, json={'interfaces': interfaces})
+
+    def can_list(self, gateway):
+        """
+            List can buses
+        """
+        url = 'gateway/{}/canbus/list'.format(quote(gateway))
+        return self.get(url)
+
+    def can_send(self, gateway, interface, frames):
         """
             Send one or more frames on CAN bus
         """
         url = 'gateway/{}/canbus/send'.format(quote(gateway))
-        return self.post(url, json={'frames': [frame._asdict() for frame in frames]})
+        frames = [frame._asdict() for frame in frames]
+        return self.post(url, json={'interface': interface, 'frames': frames})
 
-    def can_dump(self, gateway, can_options):
+    def can_dump(self, gateway, interface, can_options):
         """
             Dump frames from CAN bus
         """
         url = 'gateway/{}/canbus/dump'.format(quote(gateway))
-        return self.post(url, json={'can_options': can_options})
+        return self.post(url, json={'interface': interface, 'can_options': can_options})
+
+    def read_adc(self, gateway, channel, average_count, output):
+        """
+            Read the ADC
+        """
+        data = {
+            'channel': channel,
+            'average_count': average_count,
+            'output': output
+        }
+        url = 'gateway/{}/adc/read'.format(quote(gateway))
+        return self.post(url, json=data)
 
 
 class LagerContext:  # pylint: disable=too-few-public-methods
@@ -424,6 +454,8 @@ class LagerContext:  # pylint: disable=too-few-public-methods
         """
         if socktype == 'job':
             path = f'/ws/job/{kwargs["job_id"]}'
+        elif socktype == 'jl-tunnel':
+            path = f'/ws/gateway/{kwargs["gateway_id"]}/gdb-tunnel/2331'
         elif socktype == 'gdb-tunnel':
             path = f'/ws/gateway/{kwargs["gateway_id"]}/gdb-tunnel/3333'
         elif socktype == 'openocd-tunnel':
@@ -491,6 +523,7 @@ def ensure_debugger_running(gateway, ctx):
     if not gateway_status['running']:
         click.secho('Gateway debugger is not running. Please use `lager connect` to run it', fg='red', err=True)
         ctx.exit(1)
+    return gateway_status
 
 class CIEnvironment(Enum):
     """
