@@ -47,7 +47,7 @@ def _do_exit(exit_code):
 @click.pass_context
 @click.argument('runnable', required=False, type=click.Path(exists=True))
 @click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
-@click.option('--image', default='lagerdata/gatewaypy3:v0.1.51', help='Docker image to use for running script')
+@click.option('--image', default='lagerdata/gatewaypy3:v0.1.61', help='Docker image to use for running script')
 @click.option(
     '--env',
     multiple=True, type=EnvVarType(), help='Environment variables to set for the python script. '
@@ -61,8 +61,9 @@ def _do_exit(exit_code):
 @click.option('--kill', is_flag=True, default=False, help='Terminate a running python script')
 @click.option('--signal', 'signum', type=click.INT, default=signal.SIGTERM, help='Signal to use with --kill', show_default=True)
 @click.option('--timeout', type=click.INT, required=False, help='Max runtime in seconds for the python script')
+@click.option('--detach', '-d', is_flag=True, required=False, default=False, help='Detach')
 @click.argument('args', nargs=-1)
-def python(ctx, runnable, gateway, image, env, passenv, kill, signum, timeout, args):
+def python(ctx, runnable, gateway, image, env, passenv, kill, signum, timeout, detach, args):
     """
         Run a python script on the gateway
     """
@@ -81,6 +82,7 @@ def python(ctx, runnable, gateway, image, env, passenv, kill, signum, timeout, a
     post_data = [
         ('image', image),
         ('stdout_is_stderr', stdout_is_stderr()),
+        ('detach', '1' if detach else '0'),
     ]
     post_data.extend(
         zip(itertools.repeat('args'), args)
