@@ -4,13 +4,15 @@
     Job status output functions
 """
 try:
-    _CURSES_IMPORT_FAILED = False
-    import curses
+    _TERMIOS_IMPORT_FAILED = False
+    import termios
+    import tty
 except (ImportError, ModuleNotFoundError) as exc:
-    _CURSES_IMPORT_FAILED = exc
+    _TERMIOS_IMPORT_FAILED = exc
 import platform
 import threading
 import sys
+import os
 import select
 from functools import partial
 import bson
@@ -128,46 +130,37 @@ class TTYIO:
         Class for doing I/O with a TTY managed by curses
     """
     def __init__(self, line_ending=b''):
-        stdscr = curses.initscr()
-        curses.noecho()
-        curses.cbreak()
-        stdscr.keypad(True)
-        stdscr.scrollok(True)
-        self.stdscr = stdscr
+        self.stdin_fileno = sys.stdin.fileno()
+        self.stdout_fileno = sys.stdout.fileno()
+        self.old_settings = termios.tcgetattr(self.stdin_fileno)
+        tty.setraw(self.stdin_fileno)
         self.line_ending = line_ending
 
     def shutdown(self):
         """
             Restore previous TTY settings
         """
-        curses.nocbreak()
-        self.stdscr.keypad(False)
-        curses.echo()
-        curses.endwin()
+        termios.tcsetattr(self.stdin_fileno, termios.TCSADRAIN, self.old_settings)
 
-    def output(self, data):
+    def output(self, data, fg=None, flush=False):
         """
             Output some data to the TTY
         """
-        self.stdscr.addstr(data)
-        self.stdscr.refresh()
+        os.write(self.stdout_fileno, data)
 
     def read(self):
         """
             Read a key from the TTY
         """
-        char = self.stdscr.getch()
-        if char == -1:
+        char = os.read(self.stdin_fileno, 1)
+        if char == b'':
             raise EOFError
-        if char == 3:
+        if char == b'\x03':
             raise KeyboardInterrupt
 
-        if char <= 255:
-            parsed = char.to_bytes(1, byteorder='little')
-            if char == 10:
-                return self.line_ending or parsed
-            return parsed
-        return None
+        if char == b'\r':
+            return self.line_ending or char
+        return char
 
 class StandardIO:
     """
@@ -179,12 +172,16 @@ class StandardIO:
         """
         pass
 
-    def output(self, data):
+    def output(self, data, fg=None, flush=False):
         """
             Send some data to stdout
         """
-        click.echo(data, nl=False)
-        sys.stdout.flush()
+        if fg:
+            click.secho(data, nl=False, fg=fg)
+        else:
+            click.echo(data, nl=False)
+        if flush:
+            sys.stdout.flush()
 
     def read(self):
         """
@@ -202,7 +199,7 @@ class StandardIO:
 
 
 @retry(reraise=True, sleep=trio.sleep, stop=stop_after_attempt(4), wait=wait_fixed(2), retry=retry_if_exception_type(trio_websocket.ConnectionRejected))
-async def display_job_output(connection_params, test_runner, interactive, line_ending, message_timeout, overall_timeout, eof_timeout):
+async def display_job_output(connection_params, test_runner, interactive, line_ending, message_timeout, overall_timeout, eof_timeout, success_regex=None, failure_regex=None):
     """
         Display job output from websocket
     """
@@ -213,7 +210,7 @@ async def display_job_output(connection_params, test_runner, interactive, line_e
     else:
         io_source = StandardIO()
     try:
-        matcher = match_class(io_source)
+        matcher = match_class(io_source, success_regex, failure_regex)
         send_channel, receive_channel = trio.open_memory_channel(0)
         allow_reader = True
         if platform.system() == 'Windows' and not interactive:
@@ -233,13 +230,13 @@ async def display_job_output(connection_params, test_runner, interactive, line_e
         if io_source:
             io_source.shutdown()
 
-def run_job_output(connection_params, test_runner, interactive, line_ending, message_timeout, overall_timeout, eof_timeout, debug=False):
+def run_job_output(connection_params, test_runner, interactive, line_ending, message_timeout, overall_timeout, eof_timeout, debug=False, success_regex=None, failure_regex=None):
     """
         Run async task to get job output from websocket
     """
-    if interactive and _CURSES_IMPORT_FAILED:
-        click.echo(_CURSES_IMPORT_FAILED, err=True)
-        click.echo('Please install the windows-curses module before using --interactive (pip install windows-curses)')
+    if interactive and _TERMIOS_IMPORT_FAILED:
+        click.echo(_TERMIOS_IMPORT_FAILED, err=True)
+        click.echo('Interactive terminal not currently supported by Windows; please try running in Docker.', err=True)
         click.get_current_context().exit(1)
 
     if not line_ending:
@@ -252,7 +249,7 @@ def run_job_output(connection_params, test_runner, interactive, line_ending, mes
         raise ValueError('Invalid line ending')
 
     try:
-        matcher = trio.run(display_job_output, connection_params, test_runner, interactive, line_ending, message_timeout, overall_timeout, eof_timeout)
+        matcher = trio.run(display_job_output, connection_params, test_runner, interactive, line_ending, message_timeout, overall_timeout, eof_timeout, success_regex, failure_regex)
         click.get_current_context().exit(matcher.exit_code)
     except trio.TooSlowError:
         suffix = '' if overall_timeout == 1 else 's'
